SpringTimeStep

Struct SpringTimeStep 

pub struct SpringTimeStep<F> { /* private fields */ }
Cached coefficients for a spring, based on its configuration and a particular time step.

Used to efficiently update one or more springs that share the same configuration.

Usage

To derive a SpringTimeStep, you must first get a SpringParams from a SpringConfig:

// configure your spring...
let config = SpringConfig::new(5.0, 0.75);
let mut spring = Spring::new();

// derive its state
let state = SpringParams::from(config);

// then, either create your own `SpringTimeStep`...
let time_step = SpringTimeStep::new(state, delta_time);
spring.update(time_step);

// or let `Spring::update_single` do it for you
spring.update_single(state, delta_time);

Implementations

Source

impl<F: Float> SpringTimeStep<F>

pub fn new(state: impl Into<SpringParams<F>>, delta: F) -> Self

Derive a spring time step from a particular delta time.

pub fn update_many(self, springs: &mut [&mut Spring<F>])

Update multiple springs using this time step. Simply calls Spring::update on each passed spring.