pub struct SpringCollection<F, const N: usize> { /* private fields */ }Expand description
A fixed-size collection of springs that all share the same spring parameters. Useful for creating springs over multiple dimensions (i.e. 2D or 3D springs).
Implementations
Sourceimpl<F: Float, const N: usize> SpringCollection<F, N>
impl<F: Float, const N: usize> SpringCollection<F, N>
Sourcepub fn from_equilibrium(
params: impl Into<SpringParams<F>>,
equilibrium: F,
) -> Self
pub fn from_equilibrium( params: impl Into<SpringParams<F>>, equilibrium: F, ) -> Self
Construct N springs, all starting at a specified equilibrium.
Sourcepub fn from_equilibriums(
params: impl Into<SpringParams<F>>,
equilibriums: [F; N],
) -> Self
pub fn from_equilibriums( params: impl Into<SpringParams<F>>, equilibriums: [F; N], ) -> Self
Construct N springs, each with a particular equilibrium.
Sourcepub fn update(&mut self, delta: F)
pub fn update(&mut self, delta: F)
Update all springs over the specified delta. Constructs a new SpringTimeStep
for this usage.
Sourcepub fn update_with(&mut self, time_step: SpringTimeStep<F>)
pub fn update_with(&mut self, time_step: SpringTimeStep<F>)
Update all springs using the specified time_step.
Note: this time step need not be derived from SpringCollection::params.
The implementation of this method uses all constants from time_step.
Sourceimpl<F: Float, const N: usize> SpringCollection<F, N>
impl<F: Float, const N: usize> SpringCollection<F, N>
Sourceimpl<F: Float, const N: usize> SpringCollection<F, N>
impl<F: Float, const N: usize> SpringCollection<F, N>
Sourcepub fn velocities(&self) -> &[F; N]
pub fn velocities(&self) -> &[F; N]
The array of current spring $plural.
Sourcepub fn velocities_mut(&mut self) -> &mut [F; N]
pub fn velocities_mut(&mut self) -> &mut [F; N]
Mutable reference of current spring velocities.
Sourceimpl<F: Float, const N: usize> SpringCollection<F, N>
impl<F: Float, const N: usize> SpringCollection<F, N>
Sourcepub fn equilibriums(&self) -> &[F; N]
pub fn equilibriums(&self) -> &[F; N]
The array of current spring $plural.
Sourcepub fn equilibriums_mut(&mut self) -> &mut [F; N]
pub fn equilibriums_mut(&mut self) -> &mut [F; N]
Mutable reference of current spring equilibriums.